{% extends "layout.html" %}
{% load i18n %}

{% block title %}
{{ offer.name }} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
	<a href="{% url promotions:home %}">{% trans "Home" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="#">{% trans "Offers" %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active">{{ offer.name }}</li>
</ul>
{% endblock %}

{% block headertext %}
{{ offer.name }}
{% endblock %}

{% block content %}

	{% if not offer.is_active %}
	<div class="alert alert-error">{% trans " This offer has expired " %}</div>
	{% endif %}

    {% if offer.description %}
	<div class="well">
		{{ offer.description|safe }}
	</div>
    {% endif %}

    {% if upsell_message %}
    <div class="well">
        <h3>{% trans "What you need to do" %}</h3>
        <p>{{ upsell_message }}</p>
    </div>
    {% endif %}

    {% if products.count %}
		<section>
			<div class="mod">
				{% include "partials/pagination.html" %}
				<ol class="products four">
					{% for product in products %}
					<li>{% include "catalogue/partials/product.html" %}</li>
					{% endfor %}
				</ol>
				{% include "partials/pagination.html" %}
			</div>
		</section>
    {% else %}
	<p class="nonefound">{% trans "No products found." %}</p>
    {% endif %}
{% endblock content %}
