{% load currency_filters %}
{% load thumbnail %}
{% load i18n %}

<article class="product_pod">
    <div class="image_container">
        {% with image=product.primary_image %}
        {% thumbnail image.original "400x400" upscale=False as thumb %}
        <a href="{{ product.get_absolute_url }}"><img class="thumbnail" src="{{ thumb.url }}" alt="{{ product.get_title }}"></a>
        {% endthumbnail %}
        {% endwith %}
    </div>
    <h3><a href="{{ product.get_absolute_url }}">{{ product.get_title|truncatewords:4 }}</a></h3>
    <div class="product_price">
        {% include "catalogue/partials/stock_record.html" %}
        {% include "catalogue/partials/add_to_basket_form_compact.html" %}
    </div>
</article>