{% extends 'dashboard/layout.html' %}
{% load currency_filters %}
{% load i18n %}

{% block title %}
{% trans "Delete offer" %} | {% trans "Offer management" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
	<a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
	<a href="{% url dashboard:offer-list %}">{% trans "Offers" %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active">{% trans "Delete offer?" %}</li>
</ul>
{% endblock %}

{% block headertext %}
{% trans "Delete offer?" %}
{% endblock %}

{% block dashboard_content %}
<form action="." method="post" class="">
	{% csrf_token %}
	{% include 'dashboard/offers/partials/offer.html' %}

	<div class="form-actions">
		<button class="btn btn-large btn-danger" type="submit">{% trans "Delete" %}</button> or
		<a href="{% url dashboard:offer-list %}">{% trans "cancel" %}</a>
	</div>
</form>
{% endblock dashboard_content %}
