{% load currency_filters %}
{% load thumbnail %}
{% load i18n %}

<article class="product_pod">
    <div class="image_container">
		{% with image=product.primary_image %}
		{% thumbnail image.original "400x400" upscale=False as thumb %}
		<a href="{{ product.get_absolute_url }}"><img src="{{ thumb.url }}" alt="{{ product.get_title }}" class="thumbnail"></a>
		{% endthumbnail %}
		{% endwith %}
    </div>
    {% block product_review %}
        {% with reviews=product.reviews.all %}
            {% if reviews %}
                <ul class="review_count">       
                {% for review in reviews %}
                    <li class="{{ review.score }}">{{ review.score }}</li>
                {% endfor %}
                </ul>
            {% else %}
			<p class="star">{% trans "No Rating" %}</p>
            {% endif %}
        {% endwith %}
    {% endblock product_review %}
    
    <h3><a href="{{ product.get_absolute_url }}">{{ product.get_title|truncatewords:5 }}</a></h3>
    
    <div class="product_price">
        {% include "catalogue/partials/stock_record.html" %}
        {% include "catalogue/partials/add_to_basket_form_compact.html" %}
   </div>
</article>
